Authentication

BHL Authentication

For access to Biodiveristy Heritage Library data, you'll need an API key from them. To get one fill out the brief form at http://www.biodiversitylibrary.org/getapikey.aspx - they'll ask for your name and email address.

To use the key, do one of:

  • pass it in the key parameter in sp_lit_meta()

  • store as an environment variable (as BHL_KEY) either in your .Renviron file, or wherever you store your environment variables (e.g., .bashrc, or .bash_profile, or .zshrc)

  • store as an R option (as bhl_key) in your .Rprofile file